@@ -1,19 +1,20 @@
 /*
- * Copyright (c) 2010-2019 Belledonne Communications SARL.
+ * Copyright (c) 2010-2022 Belledonne Communications SARL.
  *
- * This file is part of oRTP.
+ * This file is part of oRTP 
+ * (see https://gitlab.linphone.org/BC/public/ortp).
  *
  * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU Affero General Public License as
+ * published by the Free Software Foundation, either version 3 of the
+ * License, or (at your option) any later version.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * GNU Affero General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Affero General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -49,12 +50,18 @@ struct _OrtpEventData{
 			bool_t verified;
 			bool_t cache_mismatch;
 			bool_t pad[2];
+			int cipherAlgo;
+			int keyAgreementAlgo;
+			int hashAlgo;
+			int authTagAlgo;
+			int sasAlgo;
 		} zrtp_info;
 		OrtpSocketType socket_type;
 		uint32_t received_rtt_character;
 		bool_t congestion_detected;
 		float video_bandwidth_available;
 		int jitter_min_size_for_nack;
+        uint16_t reconstructed_packet_seq_number;
 	} info;
 };
 
@@ -68,26 +75,33 @@ extern "C"{
 ORTP_PUBLIC OrtpEvent * ortp_event_new(OrtpEventType tp);
 ORTP_PUBLIC OrtpEventType ortp_event_get_type(const OrtpEvent *ev);
 /* type is one of the following*/
-#define ORTP_EVENT_STUN_PACKET_RECEIVED		1
-#define ORTP_EVENT_PAYLOAD_TYPE_CHANGED 	2
-#define ORTP_EVENT_TELEPHONE_EVENT		3
-#define ORTP_EVENT_RTCP_PACKET_RECEIVED		4 /**<when a RTCP packet is received from far end */
-#define ORTP_EVENT_RTCP_PACKET_EMITTED		5 /**<fired when oRTP decides to send an automatic RTCP SR or RR */
-#define ORTP_EVENT_ZRTP_ENCRYPTION_CHANGED	6
-#define ORTP_EVENT_ZRTP_SAS_READY		7
-#define ORTP_EVENT_ICE_CHECK_LIST_PROCESSING_FINISHED	8
-#define ORTP_EVENT_ICE_SESSION_PROCESSING_FINISHED	9
-#define ORTP_EVENT_ICE_GATHERING_FINISHED		10
-#define ORTP_EVENT_ICE_LOSING_PAIRS_COMPLETED		11
-#define ORTP_EVENT_ICE_RESTART_NEEDED			12
-#define ORTP_EVENT_DTLS_ENCRYPTION_CHANGED		13
-#define ORTP_EVENT_RTT_CHARACTER_RECEIVED		15
-#define ORTP_EVENT_CONGESTION_STATE_CHANGED		16
-#define ORTP_EVENT_ZRTP_CACHE_MISMATCH			17
-#define ORTP_EVENT_ZRTP_PEER_VERSION_OBSOLETE		18
-#define ORTP_EVENT_NEW_VIDEO_BANDWIDTH_ESTIMATION_AVAILABLE             19
-#define ORTP_EVENT_ICE_DEACTIVATION_NEEDED		20
-#define ORTP_EVENT_JITTER_UPDATE_FOR_NACK		21
+
+#define ORTP_EVENT_STUN_PACKET_RECEIVED				1
+#define ORTP_EVENT_PAYLOAD_TYPE_CHANGED				2
+#define ORTP_EVENT_TELEPHONE_EVENT				3
+#define ORTP_EVENT_RTCP_PACKET_RECEIVED				4 /**<when a RTCP packet is received from far end */
+#define ORTP_EVENT_RTCP_PACKET_EMITTED				5 /**<fired when oRTP decides to send an automatic RTCP SR or RR */
+#define ORTP_EVENT_ZRTP_ENCRYPTION_CHANGED			6
+#define ORTP_EVENT_ZRTP_SAS_READY				7
+#define ORTP_EVENT_ICE_CHECK_LIST_PROCESSING_FINISHED		8
+#define ORTP_EVENT_ICE_SESSION_PROCESSING_FINISHED		9
+#define ORTP_EVENT_ICE_GATHERING_FINISHED			10
+#define ORTP_EVENT_ICE_LOSING_PAIRS_COMPLETED			11
+#define ORTP_EVENT_ICE_RESTART_NEEDED				12
+#define ORTP_EVENT_ICE_CHECK_LIST_DEFAULT_CANDIDATE_VERIFIED    25
+#define ORTP_EVENT_DTLS_ENCRYPTION_CHANGED			13
+#define ORTP_EVENT_RTT_CHARACTER_RECEIVED			15
+#define ORTP_EVENT_CONGESTION_STATE_CHANGED			16
+#define ORTP_EVENT_ZRTP_CACHE_MISMATCH				17
+#define ORTP_EVENT_ZRTP_PEER_VERSION_OBSOLETE			18
+#define ORTP_EVENT_ZRTP_PEER_REQUEST_GOCLEAR			19
+#define ORTP_EVENT_ZRTP_PEER_ACK_GOCLEAR			20
+#define ORTP_EVENT_NEW_VIDEO_BANDWIDTH_ESTIMATION_AVAILABLE	21
+#define ORTP_EVENT_ICE_DEACTIVATION_NEEDED			22
+#define ORTP_EVENT_JITTER_UPDATE_FOR_NACK			23
+#define ORTP_EVENT_SOURCE_PACKET_RECONSTRUCTED			24
+#define ORTP_EVENT_DO_NOT_USE_RESERVED				25  /* taken by ORTP_EVENT_ICE_CHECK_LIST_DEFAULT_CANDIDATE_VERIFIED */
+
 
 ORTP_PUBLIC OrtpEventData * ortp_event_get_data(OrtpEvent *ev);
 ORTP_PUBLIC void ortp_event_destroy(OrtpEvent *ev);
